==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateStatusFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateStatusFluent<A extends CertificateStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,CertificateCondition item);
  public A setToConditions(Integer index,CertificateCondition item);
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... items);
  public A addAllToConditions(Collection<CertificateCondition> items);
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... items);
  public A removeAllFromConditions(Collection<CertificateCondition> items);
  public A removeMatchingFromConditions(Predicate<CertificateConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateCondition> getConditions();
  public List<CertificateCondition> buildConditions();
  public CertificateCondition buildCondition(Integer index);
  public CertificateCondition buildFirstCondition();
  public CertificateCondition buildLastCondition();
  public CertificateCondition buildMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public A withConditions(List<CertificateCondition> conditions);
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... conditions);
  public Boolean hasConditions();
  public CertificateStatusFluent.ConditionsNested<A> addNewCondition();
  public CertificateStatusFluent.ConditionsNested<A> addNewConditionLike(CertificateCondition item);
  public CertificateStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,CertificateCondition item);
  public CertificateStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public CertificateStatusFluent.ConditionsNested<A> editFirstCondition();
  public CertificateStatusFluent.ConditionsNested<A> editLastCondition();
  public CertificateStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public String getLastFailureTime();
  public A withLastFailureTime(String lastFailureTime);
  public Boolean hasLastFailureTime();
  public String getNextPrivateKeySecretName();
  public A withNextPrivateKeySecretName(String nextPrivateKeySecretName);
  public Boolean hasNextPrivateKeySecretName();
  public String getNotAfter();
  public A withNotAfter(String notAfter);
  public Boolean hasNotAfter();
  public String getNotBefore();
  public A withNotBefore(String notBefore);
  public Boolean hasNotBefore();
  public String getRenewalTime();
  public A withRenewalTime(String renewalTime);
  public Boolean hasRenewalTime();
  public Integer getRevision();
  public A withRevision(Integer revision);
  public Boolean hasRevision();
  public interface ConditionsNested<N> extends Nested<N>,CertificateConditionFluent<CertificateStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateStatusFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateStatusFluent<A extends CertificateStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,CertificateCondition item);
  public A setToConditions(int index,CertificateCondition item);
  public A addToConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... items);
  public A addAllToConditions(Collection<CertificateCondition> items);
  public A removeFromConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... items);
  public A removeAllFromConditions(Collection<CertificateCondition> items);
  public A removeMatchingFromConditions(Predicate<CertificateConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateCondition> getConditions();
  public List<CertificateCondition> buildConditions();
  public CertificateCondition buildCondition(int index);
  public CertificateCondition buildFirstCondition();
  public CertificateCondition buildLastCondition();
  public CertificateCondition buildMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public A withConditions(List<CertificateCondition> conditions);
  public A withConditions(io.fabric8.certmanager.api.model.v1alpha3.CertificateCondition... conditions);
  public Boolean hasConditions();
  public CertificateStatusFluent.ConditionsNested<A> addNewCondition();
  public CertificateStatusFluent.ConditionsNested<A> addNewConditionLike(CertificateCondition item);
  public CertificateStatusFluent.ConditionsNested<A> setNewConditionLike(int index,CertificateCondition item);
  public CertificateStatusFluent.ConditionsNested<A> editCondition(int index);
  public CertificateStatusFluent.ConditionsNested<A> editFirstCondition();
  public CertificateStatusFluent.ConditionsNested<A> editLastCondition();
  public CertificateStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<CertificateConditionBuilder> predicate);
  public String getLastFailureTime();
  public A withLastFailureTime(String lastFailureTime);
  public Boolean hasLastFailureTime();
  public String getNextPrivateKeySecretName();
  public A withNextPrivateKeySecretName(String nextPrivateKeySecretName);
  public Boolean hasNextPrivateKeySecretName();
  public String getNotAfter();
  public A withNotAfter(String notAfter);
  public Boolean hasNotAfter();
  public String getNotBefore();
  public A withNotBefore(String notBefore);
  public Boolean hasNotBefore();
  public String getRenewalTime();
  public A withRenewalTime(String renewalTime);
  public Boolean hasRenewalTime();
  public Integer getRevision();
  public A withRevision(Integer revision);
  public Boolean hasRevision();
  public interface ConditionsNested<N> extends Nested<N>,CertificateConditionFluent<CertificateStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
